@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 #include <string.h>
 #include <asm/types.h>
 
-#include <linux/vzquota.h>
-#include <linux/vzctl_quota.h>
+#include "linux/vzquota.h"
+#include "linux/vzctl_quota.h"
 
 #include "kcompat.h"
 
