@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -500,7 +500,8 @@ static void quota_on()
 	
 	if ((qd.head.flags & QUOTA_DIRTY) && !rescan && !(option & FL_NOCHECK))
 	{
-		debug(LOG_INFO, "quota usage is invalid for id %d, recalculating disk usage...\n", quota_id);
+		debug(LOG_WARNING, "quota usage is invalid for id %d, "
+			"recalculating disk usage...\n", quota_id);
 		rescan = 1;
 	}
 
