@@ -1,13 +1,19 @@
 /*
- * Copyright (C) 2000-2005 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
  *
- * This file may be distributed under the terms of the Q Public License
- * as defined by Trolltech AS of Norway and appearing in the file
- * LICENSE.QPL included in the packaging of this file.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
- * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
- * PURPOSE.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include <dirent.h>
@@ -38,18 +44,12 @@ int main(int argc, char **argv)
 	parse_global_options(&argc, &argv, usg);
 	
 	mount_point = globolize_path(argv[0]);
-#ifdef L2
 	info.ugid_stat = NULL;
-#endif	
 	scan(&info, mount_point);
 
 	printf("quota usage for %s\n", mount_point);
 	printf("%11s%11s\n","blocks", "inodes");
-#ifndef L2
-	printf("%11u%11u\n", block_view(info.size), info.inodes);
-#else
 	printf("%11u%11u\n", ker2block(info.size), info.inodes);
-#endif
 	exit(0);
 }
 
